@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
 
 ##  generate_training_and_test_data_symbolic.pl
 
@@ -17,10 +17,8 @@ my $training_data_gen = TrainingAndTestDataGeneratorSymbolic->new(
                               parameter_file    => $parameter_file,
                               number_of_samples_for_training => 200,
                               number_of_samples_for_testing => 20,
-#                              debug => 1
                         );
 
 $training_data_gen->read_parameter_file_symbolic();
 $training_data_gen->gen_symbolic_training_and_test_data();
 
-#
